# frozen_string_literal: true

require "support/simplecov"
require "support/test_case"

Byebug::TestCase.before_suite
